# extras

Extras directory that contains functions that need additional dependencies to work.

| File        | Description |
| :---------: | :---------: |
| fods.py     | FOD generation |
| libxc.py    | Use Libxc functionals |
| viewer.py   | Notebook display functions |
